@@ -1,6 +1,6 @@
 from .loader import conn
 from .exceptions import ExtraArgException, ManyPrimaryKeysException, NoPrimaryKeysException, ArgException, RequiredArgException
-from .constants import SELECT_QUERY, UPDATE_QUERY, INSERT_QUERY, DELETE_QUERY
+from .constants import SELECT_QUERY, UPDATE_QUERY, INSERT_QUERY, DELETE_QUERY, CREATE_QUERY, WHERE_QUERY
 from .db import Model, Field, StringField, BooleanField, IntegerField, DateTimeField
 
 
